@@ -11,6 +11,7 @@ from .enums import (
     CongestionSeriesSplit,
     CongestionSeriesUnit,
     CongestionVesselsOperation,
+    CongestionVesselsPeriod,
     ContractsTypes,
     FleetDevelopmentSeriesAggregationMetric,
     FleetDevelopmentSeriesMetric,
@@ -30,6 +31,7 @@ from .enums import (
     FleetUtilizationSeriesSplit,
     FleetUtilizationSeriesUnit,
     FleetUtilizationSeriesVesselsState,
+    FleetUtilizationVesselsPeriod,
     FleetUtilizationVesselsState,
     FleetUtilizationVesselsUnit,
     FlowsDirection,
@@ -64,6 +66,7 @@ __all__ = [
     "BallastCapacitySeriesUnit",
     "CongestionSeriesSplit",
     "CongestionSeriesPeriod",
+    "CongestionVesselsPeriod",
     "CongestionSeriesMetric",
     "CongestionSeriesOperation",
     "CongestionSeriesUnit",
@@ -89,6 +92,7 @@ __all__ = [
     "FleetMetricsVesselsMeasurementUnit",
     "FleetUtilizationSeriesMetric",
     "FleetUtilizationSeriesPeriod",
+    "FleetUtilizationVesselsPeriod",
     "FleetUtilizationSeriesSplit",
     "FleetUtilizationSeriesUnit",
     "FleetUtilizationSeriesVesselsState",
