@@ -6,6 +6,7 @@ from kpler.sdk import Platform
 from kpler.sdk.client import KplerClient
 from kpler.sdk.configuration import Configuration
 from kpler.sdk.helpers import (
+    process_bool_parameter,
     process_date_parameter,
     process_enum_parameter,
     process_enum_parameters,
@@ -40,6 +41,11 @@ class FleetUtilizationVessels(KplerClient):
         gte: Optional[int] = None,
         lte: Optional[int] = None,
         vessel_types: Optional[List[Enum]] = None,
+        period: Optional[Enum] = None,
+        previous_zones: Optional[List[str]] = None,
+        next_zones: Optional[List[str]] = None,
+        vessel_directions: Optional[List[str]] = None,
+        distinct_aggregation: bool = False,
     ):
 
         """
@@ -56,6 +62,11 @@ class FleetUtilizationVessels(KplerClient):
             gte: Optional[int] Get vessels with deadweight/capacity greater or equals to this value by default 0
             lte: Optional[int] Get vessels with deadweight/capacity lower or equals to this value by default 606550
             vessel_types: Optional[List[Enum]] ``VesselTypesDry`` ``VesselTypesLNG`` ``VesselTypesLPG``
+            period: Optional[Enum] ``FleetUtilizationVesselsPeriod``
+            previous_zones: Optional[List[str]] Names of zones (port/region/country/continent) the vessel is coming from
+            next_zones: Optional[List[str]] Names of zones (port/region/country/continent) the vessel is going to
+            vessel_directions: Optional[List[str]] Names of the vessel’s course of direction on the given day
+            distinct_aggregation: Option[bool] Show or hide distinct vessels by default false
 
         Examples:
             >>> from datetime import date
@@ -94,5 +105,10 @@ class FleetUtilizationVessels(KplerClient):
             "gte": gte,
             "lte": lte,
             "vesselTypes": process_enum_parameters(vessel_types),
+            "period": process_enum_parameter(period),
+            "previousZones": process_list_parameter(previous_zones),
+            "nextZones": process_list_parameter(next_zones),
+            "vesselDirections": process_list_parameter(vessel_directions),
+            "distinctAggregation": process_bool_parameter(distinct_aggregation),
         }
         return self._get_dataframe(self.RESOURCE_NAME, query_parameters)
